#!/bin/sh
## SPDX-FileCopyrightText: 2022 M. Shulhan <ms@kilabit.info>
## SPDX-License-Identifier: GPL-3.0-or-later

## Script to fetch the latest commits from all git repositories under a
## directory.
##
## Usage:
##
##	$ git-update-all.sh $dir
##
## Where $dir is a path to directory that contains one or more repositories.

DIR=${1:-.}

echo "Updating all git repositories in $DIR"

dirs=$(find -L "$DIR" -maxdepth 1 -mindepth 1 -type d -print)

for repo in $dirs; do
	if [[ ! -d "$repo/.git" ]]; then
		continue
	fi

	echo ""
	echo ">>> updating $repo ..."
	git -C $repo stash --quiet
	git -C $repo pull --rebase
	git -C $repo gc --prune=now --quiet
	git -C $repo stash pop --quiet
	git -C $repo fetch --prune --prune-tags
done
