#!/bin/sh
## SPDX-FileCopyrightText: 2022 M. Shulhan <ms@kilabit.info>
## SPDX-License-Identifier: GPL-3.0-or-later

## depends=(tmux)
##
## Script that open new tmux session based on name and configuration in
## ~/.tmux.session.
##
## The .tmux.session file has the following format,
##
##	name-1 directory
##	name-2 directory
##	...
##	name-n directory
##
## Where name is unique string between each line, and directory is a path to
## directory where session will started.
##
## To open new session name-1 we run,
##
##	$ tmux-session.sh name-1
##

SESS_NAME=${1:-}
SESS_DIR=

if [[ -z "$SESS_NAME" ]]; then
	echo "empty argument, default to $SESS_NAME to $HOME"
	tmux new -c $HOME -As $SESS_NAME
	exit
fi

echo "searching for $SESS_NAME ..."
{
	while read name dir; do
		if [[ "$SESS_NAME" == "$name" ]]; then
			SESS_DIR=$dir
			break
		fi
	done
} < ~/.tmux.session

if [[ -z "$SESS_DIR" ]]; then
	echo "session $SESS_NAME not found"
	exit 1
fi

echo "opening session $SESS_NAME in $SESS_DIR"
sh -c "tmux new-session -A -c $SESS_DIR -s $SESS_NAME"
