#!/bin/sh
## SPDX-FileCopyrightText: 2022 M. Shulhan <ms@kilabit.info>
## SPDX-License-Identifier: GPL-3.0-or-later

## depends=wireguard-tools
##
## Script that activate only one wireguard connection from list of
## configuration in /etc/wireguard/*.conf or turning off all of them if no
## parameter is given.
##
## For example, given three configurations,
##
##	$ ls /etc/wireguard
##	wg0.conf wg1.conf wg2.conf
##
## Assume that current wg0 is activate, to activate wg1 and deactivate the
## rest, run
##
##	$ sudo wg-activate.sh wg1
##

exp=$1
confs=$(find -L /etc/wireguard -maxdepth 1 -type f -name "*.conf" -print)
activate=

downs=()
for f in $confs; do
	got=$(basename "${f%.conf}")
	if [[ "$exp" == "$got" ]]; then
		activate=$exp
	else
		downs+=("$got")
	fi
done

if [[ -z "$activate" ]]; then
	echo "Turning off all connections."
fi

for f in "${downs[@]}"; do
	wg-quick down $f
done

if [[ -n "$activate" ]]; then
	wg-quick up $activate
fi
